@@ -26,12 +26,14 @@ var NAVTREE =
 [
   [ "PipeWire", "index.html", [
     [ "Overview", "page_overview.html", null ],
+    [ "Configuration", "page_config.html", "page_config" ],
     [ "Programs", "page_programs.html", "page_programs" ],
     [ "Modules", "page_modules.html", "page_modules" ],
     [ "Pulseaudio Modules", "page_pulse_modules.html", "page_pulse_modules" ],
     [ "Internals", "page_internals.html", "page_internals" ],
     [ "PipeWire API", "page_api.html", "page_api" ],
-    [ "Tutorial", "page_tutorial.html", "page_tutorial" ],
+    [ "API Tutorial", "page_tutorial.html", "page_tutorial" ],
+    [ "API Reference", "topics.html", "topics" ],
     [ "Data Structures", "annotated.html", [
       [ "Data Structures", "annotated.html", "annotated_dup" ],
       [ "Data Structure Index", "classes.html", null ]
@@ -42,8 +44,28 @@ var NAVTREE =
 
 var NAVTREEINDEX =
 [
-"annotated.html",
-"structspa__audio__info__wma.html#a0bf6e6bad02abf194f2d65b5b458e7ba"
+"alloc_8h.html",
+"group__pw__data__loop.html#ga31fb97e55669c3673f4912ff08fc25f5",
+"group__pw__impl__port.html#ga5682619e17eb12d4bd4c7d70e985e08c",
+"group__pw__loop.html#ga6edef1937eb5fc176a6a36485eebf8ad",
+"group__pw__properties.html#ga88e954267fa14f49b4b7b924a0022304",
+"group__pw__session__manager.html#gacfc215ae22e6a99a5ff459f928d24daa",
+"group__spa__buffer.html#gaebb70d9cbd7c2ae9cd782216dbb51fb6",
+"group__spa__graph.html#ga3707f5819de7baf600d84a452971e0e9",
+"group__spa__log.html#gga08076f4c659566e0c3f1a8dee549b63dae9487966c0b9cefeba778422c483df64",
+"group__spa__node.html#gga12aed5ed2a6ecb69734aa3eb7da4056ba38a0f9a63830ad342b24e09879621165",
+"group__spa__param.html#gad217270e27de71f254d3d7c3d4fcf4f0",
+"group__spa__param.html#gga4077adc9cb334bd78d561f96c04eebbcad91fa4ee2ae74a39b3e8d738d692fd30",
+"group__spa__param.html#ggacb274daea0abcce261955323e7d0b1aaa5af6aa53a0bcdbd9313f8dd5d38ad706",
+"group__spa__pod.html#ga4c35e58037a9afea52cb6697bb890eba",
+"group__spa__system.html#ga2dcb97fa874ae364a19ce37d7f7ed90f",
+"page_client_impl.html#sec_page_client_impl_credentials",
+"route-types_8h.html",
+"structpw__endpoint__stream__methods.html#ab73e2f70fc5a78721ebb38118af947b5",
+"structpw__port__methods.html",
+"structspa__buffer.html#ad4c72bfda8875b33b7316af4bafb9560",
+"structspa__io__segment__video.html#ae03652e1ab2e76a1a03a63d7bd0fcc99",
+"structspa__pod__pointer__body.html"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronisation';
