@@ -1,5 +1,7 @@
 var NAVTREEINDEX20 =
 {
+"structspa__io__segment__video.html#ae03652e1ab2e76a1a03a63d7bd0fcc99":[8,6,6,14,8],
+"structspa__io__segment__video.html#ae1cc1d15b524665254cff4c3d5daeceb":[8,6,6,14,6],
 "structspa__io__segment__video.html#aefffdac704f6aa878542c37d5cc7accb":[8,6,6,14,1],
 "structspa__io__sequence.html":[8,6,6,12],
 "structspa__io__sequence.html#ab6a424dad012da97efc02bfa77ed57d9":[8,6,6,12,0],
@@ -247,7 +249,5 @@ var NAVTREEINDEX20 =
 "structspa__pod__parser__state.html#acf6a430c72bd19259ecbda4643d4b2cf":[8,6,0,17,2],
 "structspa__pod__pointer.html":[8,6,0,39],
 "structspa__pod__pointer.html#a09512c2a62eecc6518a7921d4cb0c2a7":[8,6,0,39,1],
-"structspa__pod__pointer.html#a1aefb7792b75ea7882c273abf8a2edce":[8,6,0,39,0],
-"structspa__pod__pointer__body.html":[8,6,0,38],
-"structspa__pod__pointer__body.html#a2b72ed680f7e85d988498503dc66df7e":[8,6,0,38,2]
+"structspa__pod__pointer.html#a1aefb7792b75ea7882c273abf8a2edce":[8,6,0,39,0]
 };
